mth5.io.phoenix.readers.contiguous package
==========================================

Submodules
----------

mth5.io.phoenix.readers.contiguous.decimated\_continuous\_reader module
-----------------------------------------------------------------------

.. automodule:: mth5.io.phoenix.readers.contiguous.decimated_continuous_reader
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: mth5.io.phoenix.readers.contiguous
   :members:
   :undoc-members:
   :show-inheritance:
